@@ -231,7 +231,7 @@ class BaseUtilsMixin:
         return rows, cols
 
     def _format_line(self, tag_pad, nid="ID", user="USER", url="URL",
-                     tags="TAGS"):
+                     tags="TAGS", last_mod="LAST MODIFIED"):
 
         user_pad = int(self.config.get_value("UI", "URL_pad").split('#')[0])
         url_pad = int(self.config.get_value("UI", "user_pad").split('#')[0])
@@ -240,7 +240,8 @@ class BaseUtilsMixin:
 
         return (line.format(ID=nid, USER=user,
                             URL=url, Tags=tags, user_pad=user_pad,
-                            url_pad=url_pad, tag_pad=tag_pad))
+                            url_pad=url_pad, tag_pad=tag_pad,
+                            mdate=last_mod))
 
     def _print_node_line(self, node, rows, cols, url_filter):
         if url_filter != "" and node.url.find(url_filter) == -1:
@@ -256,7 +257,8 @@ class BaseUtilsMixin:
 
         fmt = self._format_line(cols, node._id, node.username,
                                 node_url,
-                                tagstring)
+                                tagstring,
+                                node.mdate)
         formatted_entry = tools.typeset(fmt, Fore.YELLOW, False)
         print(formatted_entry)
 
@@ -277,13 +279,23 @@ class BaseUtilsMixin:
         for node_id in self._db.lazy_list_node_ids(filter=filter):
             yield node_id
 
-    def _db_entry_to_node(self, raw_node):
+    def _db_entry_to_node(self, raw_node, tags):
         # user, pass, url, notes
-        node_inst = Node.from_encrypted_entries(raw_node[1],
-                                                raw_node[2],
-                                                raw_node[3],
-                                                raw_node[4],
-                                                raw_node[5:])
+        try:
+            node_inst = Node.from_encrypted_entries(raw_node[1],
+                                                    raw_node[2],
+                                                    raw_node[3],
+                                                    raw_node[4],
+                                                    tags)
+        except AttributeError:
+            # new db format has tags after last modified field
+            node_inst = Node.from_encrypted_entries(raw_node[1],
+                                                    raw_node[2],
+                                                    raw_node[3],
+                                                    raw_node[4],
+                                                    tags,
+                                                    mdate=raw_node[5])
+
         node_inst._id = raw_node[0]
         return node_inst
 
@@ -320,12 +332,11 @@ class BaseUtilsMixin:
             print("print accepts only a single ID ...")
             return
 
-        node = self._db.get_node(nodeid)
+        node, tags = self._db.get_node(nodeid)
         if not node:  # pragma: no cover
-            print("Node not found ...")
             return
 
-        node = self._db_entry_to_node(node)
+        node = self._db_entry_to_node(node, tags)
         return node
 
 
@@ -410,16 +421,23 @@ class BaseCommands(HelpUIMixin, AliasesMixin, BaseUtilsMixin):
 
         filename = args.get('filename', 'pwman-export.csv')
         delim = args.get('delimiter', ';')
-        nodes = self._db.getnodes(list(self._db.lazy_list_node_ids()))
+
+        node_ids = list(self._db.lazy_list_node_ids())
+        nodes_tags_pairs = list(self._db.getnodes(node_ids))
 
         with open(filename, 'w') as csvfile:
             writer = csv.writer(csvfile, delimiter=delim)
             writer.writerow(['Username', 'URL', 'Password', 'Notes',
                              'Tags'])
-            for node in nodes:
-                n = Node.from_encrypted_entries(node[1], node[2], node[3],
-                                                node[4],
-                                                node[5:])
+            for node_tags in nodes_tags_pairs:
+                node = node_tags[0]
+                tags = node_tags[1]
+                n = Node.from_encrypted_entries(username=node[1],
+                                                password=node[2],
+                                                url=node[3],
+                                                notes=node[4],
+                                                tags=tags,
+                                                mdate="")
                 tags = n.tags
                 tags = ','.join(t.strip().decode() for t in tags)
                 r = list([n.username, n.url, n.password, n.notes])
@@ -480,12 +498,12 @@ class BaseCommands(HelpUIMixin, AliasesMixin, BaseUtilsMixin):
         ids = self._get_ids(args)
         for i in ids:
             i = int(i)
-            node = self._db.get_node(i)
+            node, tags = self._db.get_node(i)
             if not node:
                 print("Node not found ...")
                 return
-            node = node[1:5] + [node[5:]]
-            node = Node.from_encrypted_entries(*node)
+            node = node[1:]
+            node = Node.from_encrypted_entries(*node, tags)
             if not menu:
                 menu = CMDLoop(self.config)
                 print("Editing node %d." % (i))
@@ -514,8 +532,8 @@ class BaseCommands(HelpUIMixin, AliasesMixin, BaseUtilsMixin):
         nodeids_gen = self._lazy_get_node_ids(args)
         head = self._format_line(cols - 32)
         print(tools.typeset(head, Fore.YELLOW, False))
-        for node in self._db.getnodes(nodeids_gen):
-            self._print_node_line(self._db_entry_to_node(node), rows, cols,
+        for node, tags in self._db.getnodes(nodeids_gen):
+            self._print_node_line(self._db_entry_to_node(node, tags), rows, cols,
                                   url_filter)
 
     def do_new(self, args):  # pragma: no cover
@@ -533,6 +551,9 @@ class BaseCommands(HelpUIMixin, AliasesMixin, BaseUtilsMixin):
 
     def do_print(self, args):
         node = self._get_node(args)
+        if not node:
+            print("Node not found ...")
+            return
 
         print(node)
         flushtimeout = self.config.get_value('Global', 'cls_timeout')
